@@ -4,7 +4,7 @@
 #'
 #' @author Jose M. Pavia, \email{pavia@@uv.es}
 #' @author Rafael Romero \email{rromero@@eio.upv.es}
-#' @references Pavia, JM and Romero, R (2021). Symmetry estimating RxC vote transfer matrices from aggregate data, mimeo.
+#' @references Pavia, JM and Romero, R (2024). Symmetry estimating RxC vote transfer matrices from aggregate data. *Journal of the Royal Statistical Society, Series A – Statistics in Society*, forthcoming.  \doi{10.1093/jrsssa/qnae013}
 #'
 #' @param votes_election1 data.frame (or matrix) of order IxJ with the counts to be initially
 #'                        mapped to rows. When estimating vote transfer matrices, the votes gained by 
@@ -15,13 +15,13 @@
 #' @param votes_election2 data.frame (or matrix) of order IxK with the counts to be initially mapped 
 #'                        to columns. When estimating vote transfer matrices, the votes gained by
 #'                        the *K* political options competing on election 2 (or destination) in the *I* 
-#'                        territorial units considered. In general, The sum by rows of `votes_election1` and
+#'                        territorial units considered. The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
-#' @param integers A TRUE/FALSE value that indicates whether the problem is solved in integer values 
-#'                 in both iterations: zero (lphom) and final (including unit) solutions. If TRUE, the LP matrices
+#' @param integers A `TRUE/FALSE` value that indicates whether the problem is solved in integer values 
+#'                 in both iterations: zero (lphom) and final (including unit) solutions. If `TRUE`, the LP matrices
 #'                 are approximated to the closest integer solution solving the corresponding Integer Linear Program.
-#'                 Default, FALSE.
+#'                 Default, `FALSE`.
 #'
 #' @param solver A character string indicating the linear programming solver to be used, only
 #'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`. The package `Rsymphony`
@@ -44,6 +44,7 @@
 #'    \item{VTM.votes.units}{ An array of order JxKxI with the estimated matrix of cross-distributions of votes of elections 1 and 2 attained for each unit after congruently adjusting the **lphom_joint()** initial estimate.}
 #'    \item{EHet12}{ A matrix of order IxK measuring in each unit a distance to the homogeneity hypothesis. That is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results in each territorial unit for each option of election two. The matrix Eik.}
 #'    \item{EHet21}{ A matrix of order IxJ measuring in each unit a distance to the homogeneity hypothesis. That is, the differences under the homogeneity hypothesis between the actual recorded results and the expected results in each territorial unit for each option of election one. The matrix Eij.}
+#'    \item{deterministic.bounds}{ A list of two matrices of order JxK and two arrays of order JxKxI containing for each vote transition the lower and upper allowed proportions given the observed aggregates.}
 #'    \item{inputs}{ A list containing all the objects with the values used as arguments by the function.}
 #'    \item{solution_init}{ A list with the main outputs produced by **lphom_joint()**.}
 #'
@@ -116,10 +117,13 @@ tslphom_joint <- function(votes_election1,
 
   inic <- lphom_inic[1L:6L]
   names(inic) <- paste0(names(inic), "_init")
+  det.bounds <- bounds_compound(origin = votes_election1,
+                                destination = votes_election2, zeros = NULL)
 
   output <- list("VTM.votes" = VTM.votes, "HETe" = HETe, "VTM12" = VTM1,
               "VTM21" = VTM2, "VTM.votes.units" = VTM.votes_units, "EHet.12" = eik, 
-              "EHet.21" = eij, "inputs" = lphom_inic$inputs, "solution_init" = inic)
+              "EHet.21" = eij, "deterministic.bounds" = det.bounds, "inputs" = lphom_inic$inputs, 
+              "solution_init" = inic)
   class(output) <- c("tslphom_joint", "ei_joint", "lphom")
   return(output)
 }
